<?php
/*  
 * Analysis Console for Intrusion Databases (ACID)
 *
 * Author: Roman Danyliw <rdd@cert.org>, <roman@danyliw.com>
 *
 * Copyright (C) 2001 Carnegie Mellon University
 * (see the file 'acid_main.php' for license details)
 *
 * Purpose: routines to manipulate shared state (session
 *          information)   
 *
 */

include_once("acid_state_common.inc");

class CriteriaState
{
  var $valid_criteria_list = array("layer4",
                                  "ag",
                                  "sig",
                                  "sig_class",
                                  "sensor",
                                  "time",
                                  "ip_addr",
                                  "ip_field",
                                  "tcp_port",
                                  "tcp_flags",
                                  "tcp_field",
                                  "udp_port",
                                  "udp_field",
                                  "icmp_field",
                                  "data");

  var $clear_criteria_name;
  var $clear_criteria_element;
  var $clear_url;
  var $clear_url_params;
  //var $back_list = NULL;
  //var $back_list_cnt = 0;

  function CriteriaState($url, $params = "")
  {
    $this->clear_url = $url;
    $this->clear_url_params = $params;
  }

  function InitState()
  {
    RegisterGlobalState();
    InitGlobalState();
  }

  function ReadState()
  {
    GLOBAL $time, $time_cnt, $sig, $sig_type, 
         $sensor, $ag, $sig_class,
         $ip_addr, $ip_addr_cnt, $ip_field, $ip_field_cnt,
         $tcp_port, $tcp_port_cnt, $tcp_flags, $tcp_field, $tcp_field_cnt,
         $udp_port, $udp_port_cnt, $udp_field, $udp_field_cnt,
         $icmp_field, $icmp_field_cnt,
         $have_meta, $have_ip, $have_tcp, $have_udp, $have_icmp, $have_data,
         $layer4, $data, $data_cnt, $data_encode, $QUERY_STRING, $PHP_SELF, $debug_mode; 

    RegisterGlobalState();
    ImportGlobalState();
    
    $this->clear_criteria_name = ImportHTTPVar("clear_criteria");
    $this->clear_criteria_element = ImportHTTPVar("clear_criteria_element");

    if ( $this->clear_criteria_name != "" )
       $this->ClearCriteriaStateElement($this->clear_criteria_name,
                                        $this->clear_criteria_element);

    /*
    $this->back_list = session_register("back_list");
    $this->back_list_cnt = session_register("back_list_register");
    if ( $this->back_list == NULL )
    {
       $this->back_list[0] = "";
       $this->back_list_cnt = 0;
    }

    if ( ImportHTTPVar("back") == 1 )
    {
      $current_state = $this->back_list[--$this->back_list_cnt];
    }
    else
    {
      ++$this->back_list_cnt;
      $this->back_list[$this->back_list_cnt] = 
          array ("PHP_SELF" => $PHP_SELF,
                 "QUERY_STRING" => $QUERY_STRING );
      $this->back_list_cnt++;
       
      if ( $debug_mode > 0 ) 
      {
         ErrorMessage("Saved criteria for ".$this->back_list[$this->back_list_cnt-1]["PHP_SELF"]);
      }      

    } */
  }

  function PrintBackButton()
  {
     return;
     echo "<A HREF=\"".$this->back_list[$this->back_list_cnt-1]["PHP_SELF"].
             "?".$this->back_list[$this->back_list_cnt-1]["QUERY_STRING"]."\">Back</A>";
  }

  function GetClearCriteriaString($name, $element = "")
  {
    return '&nbsp;&nbsp;<A HREF="'.$this->clear_url.'?clear_criteria='.$name.
           '&clear_criteria_element='.$element.$this->clear_url_params.'">...clear...</A>';
  }

  function ClearCriteriaStateElement($name, $element)
  {
    GLOBAL $time, $time_cnt, $sig, $sig_type, 
         $sensor, $ag, $sig_class,
         $ip_addr, $ip_addr_cnt, $ip_field, $ip_field_cnt,
         $tcp_port, $tcp_port_cnt, $tcp_flags, $tcp_field, $tcp_field_cnt,
         $udp_port, $udp_port_cnt, $udp_field, $udp_field_cnt,
         $icmp_field, $icmp_field_cnt,
         $have_meta, $have_ip, $have_tcp, $have_udp, $have_icmp, $have_data,
         $layer4, $data, $data_cnt, $data_encode; 

    if ( in_array($name, $this->valid_criteria_list) )
    {
       ErrorMessage("Removing '$name' from criteria");
       
       switch($name)
       {
          case "sensor":
            $sensor = "";
            break;
          case "ag":
            $ag = "";
            break;
          case "sig":
            $sig = "";
            break;
          case "sig_class":
            $sig_class = "";
            break;
          case "time":
            unset($time);
            $time_cnt = 0;
            break;
          case "ip_addr":
            unset($ip_addr);
            $ip_addr_cnt = 0;
            break;
          case "ip_field":
            unset($ip_field);
            $ip_field_cnt = 0;
            break;
          case "tcp_port":
            unset($tcp_port);
            $tcp_port_cnt = 0;
            break;
          case "tcp_flags":
            unset($tcp_flags);
            $tcp_flags_cnt = 0;
            break;
          case "tcp_field":
            unset($tcp_field);
            $tcp_field_cnt = 0;
            break;
          case "udp_port":
            unset($udp_port);
            $udp_port_cnt = 0;
            break;
          case "udp_field":
            unset($udp_field);
            $udp_field_cnt = 0;
            break;
          case "icmp_field":
            unset($icmp_field);
            $icmp_field_cnt = 0;
            break;
          case "data":
            unset($data);
            $data_cnt = 0;
            break;
       }
    }
    else
      ErrorMessage("Invalid criteria element");
  }

  

}
?>
